@@ -476,7 +476,8 @@ class RedisRoot:
 
     def create_redis_model_from_redis_fields(self, django_model, redis_fields, register=True):
         new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
-        self.registered_models([new_redis_model])
+        if register:
+            self.register_models([new_redis_model])
         return new_redis_model
 
     def django_field_to_redis_field(self, django_field, save_related_models, exclude_fields):
